from setuptools import setup

setup(name='sambhawithawa',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['sambhawithawa'],
      author = 'Hasarindu Perera',
      zip_safe=False)
